--######################################################################################################
-- FILE          : DataMux64
-- RELATED FILES :
-- DESCRIPTION   : This file is essentially a Mux that provides the option to select various useful signal integrity patterns.
--               : The signal integrity patterns are chosen by an "In System Source & Probe" IP
--               : There is also a user pattern "In System Source & Probe" IP
--               :
-- AUTHOR        : James Murray 
-- DEPARTMENT    : European Regional Application Engineering
-- COMPANY       : Intel PSG
--######################################################################################################

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;


entity DataMux64 is
port
(
	Reset								: in std_logic;
	
	rx_parallel_datain      	: in  std_logic_vector(63 downto 0)    := (others => '0');
	rx_clk		: in std_logic := '0';
	
	tx_parallel_dataout      	: out  std_logic_vector(63 downto 0)    := (others => '0');
	tx_clk		: in std_logic := '0';
	
	Traffic_Tx_parallel_datain	: in  std_logic_vector(63 downto 0)    := (others => '0')
);

end entity DataMux64;

architecture rtl of DataMux64 is

-- Clock Patterns
constant Fast_CLK_Pattern			:STD_LOGIC_VECTOR(63 downto 0) := x"5555" & x"5555" & x"5555" & x"5555";
constant CLK33_Pattern				:STD_LOGIC_VECTOR(63 downto 0) := x"3333" & x"3333" & x"3333" & x"3333";
constant F0_CLK_Pattern				:STD_LOGIC_VECTOR(63 downto 0) := x"F0F0" & x"F0F0" & x"F0F0" & x"F0F0";
constant FF00_CLK_Pattern			:STD_LOGIC_VECTOR(63 downto 0) := x"FF00" & x"FF00" & x"FF00" & x"FF00";
constant FFFF0000_CLK_Pattern		:STD_LOGIC_VECTOR(63 downto 0) := x"FFFF" & x"0000" & x"FFFF" & x"0000";
constant Step_Pattern				:STD_LOGIC_VECTOR(63 downto 0) := x"FFFF" & x"FFFF" & x"0000" & x"0000";

constant FastSlowCLK_Pattern		:STD_LOGIC_VECTOR(63 downto 0) := x"FFFF" & x"5555" & x"0000" & x"AAAA";

--Impulse Patterns
constant Impulse_Pattern			:STD_LOGIC_VECTOR(63 downto 0) := x"8000" & x"0000" & x"0000" & x"0000";
constant NegImpulse_Pattern			:STD_LOGIC_VECTOR(63 downto 0) := x"EFFF" & x"FFFF" & x"FFFF" & x"FFFF";
constant MultipleImpulse			:STD_LOGIC_VECTOR(63 downto 0) := x"8000" & x"8000" & x"8000" & x"8000";
constant MultipleFastImpulse		:STD_LOGIC_VECTOR(63 downto 0) := x"8080" & x"8080" & x"8080" & x"8080";

--Combined Clk and Impulse Patterns
constant SI_Pattern					:STD_LOGIC_VECTOR(63 downto 0) := x"0000" & x"1000" & x"00FF" & x"FFFF";
constant SI_NegPattern				:STD_LOGIC_VECTOR(63 downto 0) := x"FFFF" & x"EFFF" & x"FF00" & x"0000";
constant SI_Alternating_Pattern		:STD_LOGIC_VECTOR(63 downto 0) := x"0000" & x"8000" & x"FFFF" & x"EFFF";

signal 	 User_Pattern				:STD_LOGIC_VECTOR(63 downto 0) := x"0000" & x"1000" & x"00FF" & x"FFFF";


signal TxDataSel				:STD_LOGIC_VECTOR(3 downto 0);
signal RPL_parallel_dataout 	:STD_LOGIC_VECTOR(63 downto 0);
signal Count_parallel_dataout	:STD_LOGIC_VECTOR(63 downto 0);
	  
component CLK_X64 is
PORT(
	din      	: in  std_logic_vector(63 downto 0)    := (others => '0');
	clkin		: in std_logic := '0';
	
	dout      	: out  std_logic_vector(63 downto 0)    := (others => '0');
	clkout		: in std_logic := '0'
	);
end component;
      

component TxDataSelect is
	PORT(
		source_clk : in  std_logic                    := '0'; -- source_clk.clk
		source     : out std_logic_vector(3 downto 0)         --    sources.source
	);
end component;		

component USR_Pattern is
	PORT(
		source_clk : in  std_logic                    := '0'; -- source_clk.clk
		source     : out std_logic_vector(63 downto 0)         --    sources.source
	);
end component;		
                                                           
begin                                                                                                                                     
                                                           


--xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
-- Instance components here
--xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

--############################################
-- RPL FIFO

RPL_i: CLK_X64
    port map
    (   
	din      	=> rx_parallel_datain,
	clkin		=> rx_clk,

	dout      	=> RPL_parallel_dataout,
	clkout		=> tx_clk
	);         	
	
	
Sel_i: TxDataSelect
    port map
    (   
		source_clk => tx_clk,
		source     => TxDataSel
	);
	
USR_Pattern_i: USR_Pattern
    port map
    (   
		source_clk => tx_clk,
		source     => User_Pattern
	);

		
process(tx_clk, Reset)
begin
	if Reset = '1' then
		Count_parallel_dataout <= (others => '0');
	elsif rising_edge(tx_clk) then
		Count_parallel_dataout <= Count_parallel_dataout + 1;
	end if;
end process;	
	
	
process(tx_clk, Reset)
	begin
		if Reset = '1' then
			tx_parallel_dataout <= (others => '0');
		elsif rising_edge(tx_clk) then
			case TxDataSel is
			

								
				when b"0000" =>
					tx_parallel_dataout <= Fast_CLK_Pattern;
					
				when b"0001" =>
					tx_parallel_dataout <= CLK33_Pattern;

				when b"0010" =>
					tx_parallel_dataout <= F0_CLK_Pattern;
					
				when b"0011" =>
					tx_parallel_dataout <= FF00_CLK_Pattern;					

				when b"0100" =>
					tx_parallel_dataout <= FFFF0000_CLK_Pattern;
					
				when b"0101" =>
					tx_parallel_dataout <= Step_Pattern;					
					        	   
				when b"0110" =>
					tx_parallel_dataout <= Impulse_Pattern;

				when b"0111" =>
					tx_parallel_dataout <= MultipleImpulse;			
			
				when b"1000" =>
					tx_parallel_dataout <= MultipleFastImpulse;
															
				when b"1001" =>
					tx_parallel_dataout <= NegImpulse_Pattern;					
			          	   
				when b"1010" =>
					tx_parallel_dataout <= SI_Pattern;
					
				when b"1011" =>
					tx_parallel_dataout <= SI_NegPattern;
					
				when b"1100" =>
					tx_parallel_dataout <= FastSlowCLK_Pattern;			
					
				when b"1101" =>
					tx_parallel_dataout <= User_Pattern;					-- Connected to In System Source & Probes		
					
				when b"1110" =>
					tx_parallel_dataout <= RPL_parallel_dataout; 
											
				when b"1111" =>
					tx_parallel_dataout <= Traffic_Tx_parallel_datain;
					

--#########################################################					
												
			    when others =>
			    	tx_parallel_dataout <= x"DEADBEEF" & x"DEADBEEF";
			        
			end case;
		end if;
	end process;


	
end rtl;
