--######################################################################################################
-- FILE          : LH_PHYDx[n]_Wrap
-- RELATED FILES :
-- DESCRIPTION   : This file is a wrapper file for the Stratix 10 H-Tile PHY and Tx PLLs. 
--               : N PHYs and reset controllers are generated and connected to a single TX PLL. 
--               : The TX PLL can be ATX, FPLL, or CMU. 
--               : Multiple datarates are supported at compile time rather than dynamic reconfiguration
--               :
-- AUTHOR        : James Murray 
-- DEPARTMENT    : European Regional Application Engineering
-- COMPANY       : Intel PSG
--######################################################################################################

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;


entity LH_Dx2_Wrap is
	generic(	NumChannels:integer:=0;
						TxPLL_Type:string:="ATX";
						SCLK_Select:string:="x24";
						Rate:string:="10G3";
						SIPatterns:boolean:=FALSE);						
	port
	(
		refclk						: in std_logic;
		tx_serial_data		: out std_logic_vector(NumChannels-1 downto 0);
		rx_serial_data		: in  std_logic_vector(NumChannels-1 downto 0)   := (others => '0'); 
		txclkout         : out std_logic_vector(NumChannels-1 downto 0);                     -- clk
		rxclkout         : out std_logic_vector(NumChannels-1 downto 0);                     -- clk
		clk_100						: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in					: in  std_logic_vector(0 downto 0)   := (others => '0')
	);
end entity LH_Dx2_Wrap;

architecture rtl of LH_Dx2_Wrap is

	signal tx_sclk					: std_logic_vector(0 downto 0)   := (others => '0'); --     tx_serial_clk0.clk
	signal tx_serial_clk		: std_logic_vector(0 downto 0)   := (others => '0'); --     tx_serial_clk0.clk
	signal mcgb_serial_clk	: std_logic_vector(0 downto 0)   := (others => '0'); --     tx_serial_clk0.clk	


-- Parallel CLK Signals	
	signal tx_clkout            : std_logic_vector(NumChannels-1 downto 0);
	signal rx_clkout            : std_logic_vector(NumChannels-1 downto 0);
	
-- Reset Signals
	signal pll_powerdown   			: std_logic_vector(NumChannels-1 downto 0);
	signal pll_powerdown_all		: std_logic;	
	signal pll_locked       		: std_logic_vector(0 downto 0) := (others => '0');	
	signal tx_analogreset     	: std_logic_vector(NumChannels-1 downto 0);
	signal tx_analogreset_stat 	: std_logic_vector(NumChannels-1 downto 0);	
	signal tx_digitalreset    	: std_logic_vector(NumChannels-1 downto 0);
	signal tx_digitalreset_stat	: std_logic_vector(NumChannels-1 downto 0);	
	signal tx_cal_busy        	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_analogreset     	: std_logic_vector(NumChannels-1 downto 0);                   
	signal rx_analogreset_stat 	: std_logic_vector(NumChannels-1 downto 0);                   	
	signal rx_digitalreset    	: std_logic_vector(NumChannels-1 downto 0);                   
	signal rx_digitalreset_stat	: std_logic_vector(NumChannels-1 downto 0);                   	
	signal rx_is_lockedtodata 	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_is_lockedtoref 		: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_set_lockedtodata	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_set_lockedtoref 	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_cal_busy        	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	
 	type tx_parallel_data_array is array (NumChannels-1 downto 0) of std_logic_vector(63 downto 0);  
	signal tx_parallel_data : tx_parallel_data_array; 

	type rx_parallel_data_array is array (NumChannels-1 downto 0) of std_logic_vector(63 downto 0);  
	signal rx_parallel_data : rx_parallel_data_array;
	
 	type tx_parallel_data128_array is array (NumChannels-1 downto 0) of std_logic_vector(127 downto 0);  
	signal tx_parallel_data128 : tx_parallel_data128_array; 

	type rx_parallel_data128_array is array (NumChannels-1 downto 0) of std_logic_vector(127 downto 0);  
	signal rx_parallel_data128 : rx_parallel_data128_array; 	

 	type tx_parallel_data64_array is array (NumChannels-1 downto 0) of std_logic_vector(63 downto 0);  
	signal tx_parallel_data64 : tx_parallel_data64_array; 

	type rx_parallel_data64_array is array (NumChannels-1 downto 0) of std_logic_vector(63 downto 0);  
	signal rx_parallel_data64 : rx_parallel_data64_array; 	
	 	
component LH_PHYDx9G8_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDx10G1_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDx10G3_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDx11G3_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDx12G5_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDx17G4_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDxUSR0_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDxUSR1_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDxUSR2_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_PHYDxUSR3_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_analogreset
		tx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- tx_analogreset_stat
		tx_cal_busy             : out std_logic_vector(0 downto 0);                     -- tx_cal_busy
		tx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- tx_digitalreset
		tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- tx_digitalreset_stat
		tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X'); -- tx_parallel_data
		tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		tx_serial_data          : out std_logic_vector(0 downto 0);                     -- tx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0);                    -- unused_rx_parallel_data
		unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')  -- unused_tx_parallel_data
		);
end component;

component LH_ATX9G8 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   			: out std_logic         -- clk		
		);
end component;

component LH_ATX10G1 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   			: out std_logic         -- clk		
		);
end component;

component LH_ATX10G3 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   			: out std_logic         -- clk		
		);
end component;

component LH_ATX11G3 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   : out std_logic         -- clk		
		);
end component;

component LH_ATX12G5 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   : out std_logic         -- clk		
		);
end component;

component LH_ATX17G4 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   : out std_logic         -- clk		
		);
end component;

component LH_ATXUSR0 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   : out std_logic         -- clk		
		);
end component;

component LH_ATXUSR1 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   : out std_logic         -- clk		
		);
end component;

component LH_ATXUSR2 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   : out std_logic         -- clk		
		);
end component;

component LH_ATXUSR3 is
	PORT(
		mcgb_serial_clk 			: out std_logic;        -- clk
		pll_cal_busy    			: out std_logic;        -- pll_cal_busy
		pll_locked      			: out std_logic;        -- pll_locked
		pll_refclk0     			: in  std_logic := 'X'; -- clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk   : out std_logic         -- clk		
		);
end component;

component LH_FPLL9G8 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_FPLL10G1 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_FPLL10G3 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_FPLL11G3 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_FPLL12G5 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_FPLLUSR0 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_FPLLUSR1 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_FPLLUSR2 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_FPLLUSR3 is
	PORT(
		mcgb_serial_clk       : out std_logic;                                        -- mcgb_serial_clk.clk
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;


component LH_CMU9G8 is
	PORT(
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_CMU10G1 is
	PORT(
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_CMU10G3 is
	PORT(
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_CMU11G3 is
	PORT(
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_CMUUSR0 is
	PORT(
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_CMUUSR1 is
	PORT(
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_CMUUSR2 is
	PORT(
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;

component LH_CMUUSR3 is
	PORT(
		pll_cal_busy          : out std_logic;                                        --    pll_cal_busy.pll_cal_busy
		pll_locked            : out std_logic;                                        --      pll_locked.pll_locked
		pll_refclk0           : in  std_logic                     := '0';             --     pll_refclk0.clk
		reconfig_write0       : in  std_logic                     := 'X';             -- write
		reconfig_read0        : in  std_logic                     := 'X';             -- read
		reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata0    : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest0 : out std_logic;                                        -- waitrequest
		reconfig_clk0         : in  std_logic                     := 'X';             -- clk
		reconfig_reset0       : in  std_logic                     := 'X';             -- reset
		tx_serial_clk         : out std_logic                                         --   tx_serial_clk.clk
		);
end component;
  
component Reset is
	PORT(
		clock                : in  std_logic                    := '0';             --                clock.clk
		pll_locked           : in  std_logic_vector(0 downto 0) := (others => '0'); --           pll_locked.pll_locked
		pll_select           : in  std_logic_vector(0 downto 0) := (others => '0'); --           pll_select.pll_select
		reset                : in  std_logic                    := '0';             --                reset.reset
		rx_analogreset       : out std_logic_vector(0 downto 0);                    --       rx_analogreset.rx_analogreset
		rx_analogreset_stat  : in  std_logic_vector(0 downto 0) := (others => '0'); --  rx_analogreset_stat.rx_analogreset_stat
		rx_cal_busy          : in  std_logic_vector(0 downto 0) := (others => '0'); --          rx_cal_busy.rx_cal_busy
		rx_digitalreset      : out std_logic_vector(0 downto 0);                    --      rx_digitalreset.rx_digitalreset
		rx_digitalreset_stat : in  std_logic_vector(0 downto 0) := (others => '0'); -- rx_digitalreset_stat.rx_digitalreset_stat
		rx_is_lockedtodata   : in  std_logic_vector(0 downto 0) := (others => '0'); --   rx_is_lockedtodata.rx_is_lockedtodata
		rx_ready             : out std_logic_vector(0 downto 0);                    --             rx_ready.rx_ready
		tx_analogreset       : out std_logic_vector(0 downto 0);                    --       tx_analogreset.tx_analogreset
		tx_analogreset_stat  : in  std_logic_vector(0 downto 0) := (others => '0'); --  tx_analogreset_stat.tx_analogreset_stat
		tx_cal_busy          : in  std_logic_vector(0 downto 0) := (others => '0'); --          tx_cal_busy.tx_cal_busy
		tx_digitalreset      : out std_logic_vector(0 downto 0);                    --      tx_digitalreset.tx_digitalreset
		tx_digitalreset_stat : in  std_logic_vector(0 downto 0) := (others => '0'); -- tx_digitalreset_stat.tx_digitalreset_stat
		tx_ready             : out std_logic_vector(0 downto 0)                     --             tx_ready.tx_ready
		);
end component;


component DataMux64 is
	PORT(
		Reset								: in  std_logic;
		rx_parallel_datain  : in  std_logic_vector(63 downto 0)    := (others => '0');
		rx_clk							: in  std_logic := '0';
		tx_parallel_dataout : out std_logic_vector(63 downto 0)    := (others => '0');
		tx_clk							: in  std_logic := '0';
		Traffic_Tx_parallel_datain	: in  std_logic_vector(63 downto 0)    := (others => '0')
		);
end component;


                                                               
begin                                                                                                                                     
                                                           
--xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
-- Instance components here
--xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
	
CH: for i in 0 to NumChannels-1 generate 

	Gen_PHY9G8:if Rate = "9G8" generate 
			PHY: LH_PHYDx9G8_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHY9G8;		                             

	Gen_PHY10G3:if Rate = "10G3" generate 
			PHY: LH_PHYDx10G3_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHY10G3;		  
			
	Gen_PHY10G1:if Rate = "10G1" generate 
			PHY: LH_PHYDx10G1_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHY10G1;		                             
				 
	Gen_PHY11G3:if Rate = "11G3" generate 
			PHY: LH_PHYDx11G3_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHY11G3;	
			
	Gen_PHY12G5:if Rate = "12G5" generate 
			PHY: LH_PHYDx12G5_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHY12G5;	
			
	Gen_PHY17G4:if Rate = "17G4" generate 
			PHY: LH_PHYDx17G4_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHY17G4;										                             				 

	Gen_PHYUSR0:if Rate = "USR0" generate 
			PHY: LH_PHYDxUSR0_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHYUSR0;	
			
	Gen_PHYUSR1:if Rate = "USR1" generate 
			PHY: LH_PHYDxUSR1_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHYUSR1;										                             				 

	Gen_PHYUSR2:if Rate = "USR2" generate 
			PHY: LH_PHYDxUSR2_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHYUSR2;			
			
	Gen_PHYUSR3:if Rate = "USR3" generate 
			PHY: LH_PHYDxUSR3_x1
			    port map
			    (   
					reconfig_write          => (others => '0'),
					reconfig_read           => (others => '0'),
					reconfig_address        => (others => '0'),
					reconfig_writedata      => (others => '0'),
					reconfig_readdata       => open,						
					reconfig_waitrequest    => open,						
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					tx_analogreset          => tx_analogreset(i downto i),                        
					tx_analogreset_stat     => tx_analogreset_stat(i downto i),			                
					tx_cal_busy             => tx_cal_busy(i downto i),                                 
					tx_clkout               => tx_clkout(i downto i),                                   
					tx_coreclkin            => tx_clkout(i downto i),                                               
					tx_digitalreset         => tx_digitalreset(i downto i),                       
					tx_digitalreset_stat    => tx_digitalreset_stat(i downto i),                  
					tx_parallel_data        => tx_parallel_data64(i),                           			               
					tx_serial_clk0          => tx_sclk(0 downto 0),                                  
					tx_serial_data          => tx_serial_data(i downto i),		                                  
					unused_rx_parallel_data => open,                                     
					unused_tx_parallel_data => (others => '0') 
					);
			end generate Gen_PHYUSR3;	
				                                                                  
		RST: Reset
		    port map
		    (   
				clock                 => clk_100(0),
				pll_locked            => pll_locked,
				pll_select            => (others => '0'),
				reset                 => Reset_in(0),
				rx_analogreset        => rx_analogreset(i downto i),     
				rx_analogreset_stat   => rx_analogreset_stat(i downto i),
				rx_cal_busy           => rx_cal_busy(i downto i),
				rx_digitalreset       => rx_digitalreset(i downto i),      
				rx_digitalreset_stat  => rx_digitalreset_stat(i downto i), 
				rx_is_lockedtodata    => rx_is_lockedtodata(i downto i),
				rx_ready              => open,
				tx_analogreset        => tx_analogreset(i downto i),     
				tx_analogreset_stat   => tx_analogreset_stat(i downto i),
				tx_cal_busy           => tx_cal_busy(i downto i),
				tx_digitalreset       => tx_digitalreset(i downto i),      
				tx_digitalreset_stat  => tx_digitalreset_stat(i downto i), 
				tx_ready              => open
			);		
		
		Gen_Mux:if SIPatterns = TRUE generate 		
			DataPathSel: DataMux64
				port map
				(   
					Reset									=> tx_digitalreset_stat(i),
					rx_parallel_datain   	=> rx_parallel_data64(i),
					rx_clk								=> rx_clkout(i),
					tx_parallel_dataout		=> tx_parallel_data64(i),
					tx_clk								=> tx_clkout(i),
					Traffic_Tx_parallel_datain	=> x"BCBCBCBC" & x"BCBCBCBC"	-- just putting control characters on here for now.
				);
			end generate Gen_Mux;			
		
		txclkout(i) <= tx_clkout(i);
		rxclkout(i) <= rx_clkout(i);
		
	
	end generate;     

--Using generate statments as I dont want a mux or logic on the SCLK
Gen_x24_CLK:if SCLK_Select = "x24" generate
	tx_sclk <= mcgb_serial_clk; 
end generate Gen_x24_CLK;	

Gen_x1_CLK:if SCLK_Select = "x1" generate
	tx_sclk <= tx_serial_clk; 
end generate Gen_x1_CLK;	

--#################################################
-- Generate ATX PLLs
--#################################################
Gen_ATXPLL:if TxPLL_Type = "ATX" generate 

	Gen_ATX9G8:if Rate = "9G8" generate 
		ATXPLL_i0: LH_ATX9G8
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATX9G8;
	  
	Gen_ATX10G1:if Rate = "10G1" generate 
		ATXPLL_i0: LH_ATX10G1
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATX10G1;
		  
	Gen_ATX10G3:if Rate = "10G3" generate 
		ATXPLL_i0: LH_ATX10G3
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATX10G3;
	
	Gen_ATX11G3:if Rate = "11G3" generate 
		ATXPLL_i0: LH_ATX11G3
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATX11G3;
	
	Gen_ATX12G5:if Rate = "12G5" generate 
		ATXPLL_i0: LH_ATX12G5
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATX12G5;	
	
	Gen_ATX17G4:if Rate = "17G4" generate 
		ATXPLL_i0: LH_ATX17G4
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATX17G4;	

	Gen_ATXUSR0:if Rate = "USR0" generate 
		ATXPLL_i0: LH_ATXUSR0
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATXUSR0;	
	
	Gen_ATXUSR1:if Rate = "USR1" generate 
		ATXPLL_i0: LH_ATXUSR1
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATXUSR1;	
	
	Gen_ATXUSR2:if Rate = "USR2" generate 
		ATXPLL_i0: LH_ATXUSR2
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATXUSR2;		
	
	Gen_ATXUSR3:if Rate = "USR3" generate 
		ATXPLL_i0: LH_ATXUSR3
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,
				pll_locked            => pll_locked(0),	   
				pll_refclk0           => refclk,		         
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)  
				);
	end generate Gen_ATXUSR3;	
			
end generate Gen_ATXPLL;		

			
--#################################################
-- Generate FPLLs
--#################################################			
Gen_FPLL:if TxPLL_Type = "FPLL" generate 

	Gen_FPLL9G8:if Rate = "9G8" generate  
		FPLL_i0: LH_FPLL9G8
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLL9G8;				

	Gen_FPLL10G1:if Rate = "10G1" generate  
		FPLL_i0: LH_FPLL10G1
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLL10G1;				
	
	Gen_FPLL10G3:if Rate = "10G3" generate  
		FPLL_i0: LH_FPLL10G3
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLL10G3;				

	Gen_FPLL11G3:if Rate = "11G3" generate  
		FPLL_i0: LH_FPLL11G3
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLL11G3;				

	Gen_FPLL12G5:if Rate = "12G5" generate  
		FPLL_i0: LH_FPLL12G5
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLL12G5;				
	
	Gen_FPLLUSR0:if Rate = "USR0" generate  
		FPLL_i0: LH_FPLLUSR0
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLLUSR0;				
		
	Gen_FPLLUSR1:if Rate = "USR1" generate  
		FPLL_i0: LH_FPLLUSR1
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLLUSR1;				
	
	Gen_FPLLUSR2:if Rate = "USR2" generate  
		FPLL_i0: LH_FPLLUSR2
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLLUSR2;	
	
	Gen_FPLLUSR3:if Rate = "USR3" generate  
		FPLL_i0: LH_FPLLUSR3
		    port map
		    (   
				mcgb_serial_clk       => mcgb_serial_clk(0),
				pll_cal_busy          => open,				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				);
	end generate Gen_FPLLUSR3;										
	
end generate Gen_FPLL;	
			

--#################################################
-- Generate CMU PLLs
--#################################################	
Gen_CMUPLL:if TxPLL_Type = "CMU" generate

	Gen_CMU9G8:if Rate = "9G8" generate  
		CMUPLL_i0: LH_CMU9G8
		    port map
		    (   
				pll_cal_busy          => open, 				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				); 
	end generate Gen_CMU9G8;

	Gen_CMU10G1:if Rate = "10G1" generate  
		CMUPLL_i0: LH_CMU10G1
		    port map
		    (   
				pll_cal_busy          => open, 				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				); 
	end generate Gen_CMU10G1;
	
	Gen_CMU10G3:if Rate = "10G3" generate  
		CMUPLL_i0: LH_CMU10G3
		    port map
		    (   
				pll_cal_busy          => open, 				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				); 
	end generate Gen_CMU10G3;
	
	Gen_CMUUSR0:if Rate = "USR0" generate  
		CMUPLL_i0: LH_CMUUSR0
		    port map
		    (   
				pll_cal_busy          => open, 				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				); 
	end generate Gen_CMUUSR0;
		
	Gen_CMUUSR1:if Rate = "USR1" generate  
		CMUPLL_i0: LH_CMUUSR1
		    port map
		    (   
				pll_cal_busy          => open, 				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				); 
	end generate Gen_CMUUSR1;

	Gen_CMUUSR2:if Rate = "USR2" generate  
		CMUPLL_i0: LH_CMUUSR2
		    port map
		    (   
				pll_cal_busy          => open, 				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				); 
	end generate Gen_CMUUSR2;
	
	Gen_CMUUSR3:if Rate = "USR3" generate  
		CMUPLL_i0: LH_CMUUSR3
		    port map
		    (   
				pll_cal_busy          => open, 				
				pll_locked            => pll_locked(0),		
				pll_refclk0           => refclk,	
				reconfig_write0       => '0',
				reconfig_read0        => '0',
				reconfig_address0     => (others => '0'),
				reconfig_writedata0   => (others => '0'),
				reconfig_readdata0    => open,
				reconfig_waitrequest0 => open,
				reconfig_clk0         => clk_100(0),
				reconfig_reset0       => Reset_in(0),
				tx_serial_clk         => tx_serial_clk(0)	
				); 
	end generate Gen_CMUUSR3;	
	
end generate Gen_CMUPLL;


end rtl;
