--######################################################################################################
-- FILE          : LH_GT[n]_Wrap
-- RELATED FILES :
-- DESCRIPTION   : This file is a wrapper file for the Stratix 10 H-Tile GXT PHYs and ATX PLLs
--               : Each ATX PLL can only drive two GXT channels directly. 
--               : Cascading from the Main ATX to the above and below ATX PLLs lets you drive a total of 6 channels
--               : A minimum of 1 Main ATX and PHY must always be used first
--               : The Generics let you define how many Above, Main, and Below channels you would like.
--               :
-- AUTHOR        : James Murray 
-- DEPARTMENT    : European Regional Application Engineering
-- COMPANY       : Intel PSG
--######################################################################################################

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;


entity LH_GT7_Wrap is
  generic(
    NumAboveChannels  : integer := 0;
    NumMainChannels : integer := 0;
    NumBelowChannels  : integer := 0;
    Rate              : string  := "25G8";
	 SIPatterns:boolean:= FALSE);				    
  port (
    refclk             : in  std_logic;
    abv_tx_serial_data : out std_logic_vector(NumAboveChannels-1 downto 0);
    abv_rx_serial_data : in  std_logic_vector(NumAboveChannels-1 downto 0);
    main_tx_serial_data : out std_logic_vector(NumMainChannels-1 downto 0);
    main_rx_serial_data : in  std_logic_vector(NumMainChannels-1 downto 0);
    blw_tx_serial_data : out std_logic_vector(NumBelowChannels-1 downto 0);
    blw_rx_serial_data : in  std_logic_vector(NumBelowChannels-1 downto 0);
    clk_100            : in  std_logic_vector(0 downto 0) := (others => '0');
    Reset_in           : in  std_logic_vector(0 downto 0) := (others => '0')
    );
end entity LH_GT7_Wrap;

architecture rtl of LH_GT7_Wrap is


  signal tx_sclk                  : std_logic_vector(0 downto 0)                   := (others => '0');  --     tx_serial_clk0.clk
  signal tx_serial_clk            : std_logic_vector(0 downto 0)                   := (others => '0');  --     tx_serial_clk0.clk
  signal mcgb_serial_clk          : std_logic_vector(0 downto 0)                   := (others => '0');  --     tx_serial_clk0.clk  
  signal tx_serial_clk_gxt        : std_logic_vector(0 downto 0)                   := (others => '0');  --     tx_serial_clk0.clk

  signal gxt_output_to_abv_atx    : std_logic;                                                          -- clk
  signal gxt_output_to_blw_atx    : std_logic;                                                          -- clk

  signal abv_tx_serial_clk_gxt    : std_logic_vector(0 downto 0)                   := (others => '0');  --     tx_serial_clk0.clk  
  signal main_tx_serial_clk_gxt    : std_logic_vector(0 downto 0)                   := (others => '0');  --     tx_serial_clk0.clk
  signal blw_tx_serial_clk_gxt    : std_logic_vector(0 downto 0)                   := (others => '0');  --     tx_serial_clk0.clk    

-- Parallel CLK Signals 

  signal abv_tx_clkout            : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_rx_clkout            : std_logic_vector(NumAboveChannels-1 downto 0);

  signal main_tx_clkout            : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_rx_clkout            : std_logic_vector(NumMainChannels-1 downto 0);

  signal blw_tx_clkout            : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_rx_clkout            : std_logic_vector(NumBelowChannels-1 downto 0);

-- Reset Signals
  signal abv_pll_powerdown        : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_pll_locked           : std_logic_vector(0 downto 0)                   := (others => '0');
  signal abv_tx_analogreset       : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_tx_analogreset_stat  : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_tx_digitalreset      : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_tx_digitalreset_stat : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_tx_cal_busy          : std_logic_vector(NumAboveChannels-1 downto 0)  := (others => '0');
  signal abv_rx_analogreset       : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_rx_analogreset_stat  : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_rx_digitalreset      : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_rx_digitalreset_stat : std_logic_vector(NumAboveChannels-1 downto 0);
  signal abv_rx_is_lockedtodata   : std_logic_vector(NumAboveChannels-1 downto 0)  := (others => '0');
  signal abv_rx_is_lockedtoref    : std_logic_vector(NumAboveChannels-1 downto 0)  := (others => '0');
  signal abv_rx_set_lockedtodata  : std_logic_vector(NumAboveChannels-1 downto 0)  := (others => '0');
  signal abv_rx_set_lockedtoref   : std_logic_vector(NumAboveChannels-1 downto 0)  := (others => '0');
  signal abv_rx_cal_busy          : std_logic_vector(NumAboveChannels-1 downto 0)  := (others => '0');

  signal main_pll_powerdown        : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_pll_locked           : std_logic_vector(0 downto 0)                   := (others => '0');
  signal main_tx_analogreset       : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_tx_analogreset_stat  : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_tx_digitalreset      : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_tx_digitalreset_stat : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_tx_cal_busy          : std_logic_vector(NumMainChannels-1 downto 0) := (others => '0');
  signal main_rx_analogreset       : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_rx_analogreset_stat  : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_rx_digitalreset      : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_rx_digitalreset_stat : std_logic_vector(NumMainChannels-1 downto 0);
  signal main_rx_is_lockedtodata   : std_logic_vector(NumMainChannels-1 downto 0) := (others => '0');
  signal main_rx_is_lockedtoref    : std_logic_vector(NumMainChannels-1 downto 0) := (others => '0');
  signal main_rx_set_lockedtodata  : std_logic_vector(NumMainChannels-1 downto 0) := (others => '0');
  signal main_rx_set_lockedtoref   : std_logic_vector(NumMainChannels-1 downto 0) := (others => '0');
  signal main_rx_cal_busy          : std_logic_vector(NumMainChannels-1 downto 0) := (others => '0');

  signal blw_pll_powerdown        : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_pll_locked           : std_logic_vector(0 downto 0)                   := (others => '0');
  signal blw_tx_analogreset       : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_tx_analogreset_stat  : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_tx_digitalreset      : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_tx_digitalreset_stat : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_tx_cal_busy          : std_logic_vector(NumBelowChannels-1 downto 0)  := (others => '0');
  signal blw_rx_analogreset       : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_rx_analogreset_stat  : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_rx_digitalreset      : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_rx_digitalreset_stat : std_logic_vector(NumBelowChannels-1 downto 0);
  signal blw_rx_is_lockedtodata   : std_logic_vector(NumBelowChannels-1 downto 0)  := (others => '0');
  signal blw_rx_is_lockedtoref    : std_logic_vector(NumBelowChannels-1 downto 0)  := (others => '0');
  signal blw_rx_set_lockedtodata  : std_logic_vector(NumBelowChannels-1 downto 0)  := (others => '0');
  signal blw_rx_set_lockedtoref   : std_logic_vector(NumBelowChannels-1 downto 0)  := (others => '0');
  signal blw_rx_cal_busy          : std_logic_vector(NumBelowChannels-1 downto 0)  := (others => '0');


  type abv_tx_parallel_data64_array is array (NumAboveChannels-1 downto 0) of std_logic_vector(63 downto 0);
  signal abv_tx_parallel_data64   : abv_tx_parallel_data64_array;

  type abv_rx_parallel_data64_array is array (NumAboveChannels-1 downto 0) of std_logic_vector(63 downto 0);
  signal abv_rx_parallel_data64   : abv_rx_parallel_data64_array;

  type main_tx_parallel_data64_array is array (NumMainChannels-1 downto 0) of std_logic_vector(63 downto 0);
  signal main_tx_parallel_data64   : main_tx_parallel_data64_array;

  type main_rx_parallel_data64_array is array (NumMainChannels-1 downto 0) of std_logic_vector(63 downto 0);
  signal main_rx_parallel_data64   : main_rx_parallel_data64_array;

  type blw_tx_parallel_data64_array is array (NumBelowChannels-1 downto 0) of std_logic_vector(63 downto 0);
  signal blw_tx_parallel_data64   : blw_tx_parallel_data64_array;

  type blw_rx_parallel_data64_array is array (NumBelowChannels-1 downto 0) of std_logic_vector(63 downto 0);
  signal blw_rx_parallel_data64   : blw_rx_parallel_data64_array;


  component LH_PHYGT24G3_x1 is
    port(
      reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- write
      reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- read
      reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata       : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest    : out std_logic_vector(0 downto 0);                      -- waitrequest
      reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- reset
      rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_analogreset
      rx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- rx_analogreset_stat
      rx_cal_busy             : out std_logic_vector(0 downto 0);                      -- rx_cal_busy
      rx_cdr_refclk0          : in  std_logic                     := 'X';              -- clk
      rx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_digitalreset
      rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- rx_digitalreset_stat
      rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtodata
      rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtoref
      rx_parallel_data        : out std_logic_vector(63 downto 0);                     -- rx_parallel_data
      rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_serial_data
      tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_analogreset
      tx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- tx_analogreset_stat
      tx_cal_busy             : out std_logic_vector(0 downto 0);                      -- tx_cal_busy
      tx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_digitalreset
      tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- tx_digitalreset_stat
      tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X');  -- tx_parallel_data
      tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_serial_data          : out std_logic_vector(0 downto 0);                      -- tx_serial_data
      unused_rx_parallel_data : out std_logic_vector(15 downto 0);                     -- unused_rx_parallel_data
      unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')   -- unused_tx_parallel_data
      );
  end component;
  
  component LH_ATX24G3Above is
    port(
      gxt_input_from_blw_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;

  component LH_ATX24G3Main is
    port(
      gxt_output_to_abv_atx : out std_logic;                                         -- clk
      gxt_output_to_blw_atx : out std_logic;                                         -- clk
      pll_cal_busy          : out std_logic;                                         -- pll_cal_busy
      pll_locked            : out std_logic;                                         -- pll_locked
      pll_refclk0           : in  std_logic                     := 'X';              -- clk
      reconfig_write0       : in  std_logic                     := 'X';              -- write
      reconfig_read0        : in  std_logic                     := 'X';              -- read
      reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0    : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0 : out std_logic;                                         -- waitrequest
      reconfig_clk0         : in  std_logic                     := 'X';              -- clk
      reconfig_reset0       : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt     : out std_logic                                          -- clk
      );
  end component;

  component LH_ATX24G3Below is
    port(
      gxt_input_from_abv_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;


  component LH_PHYGT25G8_x1 is
    port(
      reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- write
      reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- read
      reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata       : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest    : out std_logic_vector(0 downto 0);                      -- waitrequest
      reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- reset
      rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_analogreset
      rx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- rx_analogreset_stat
      rx_cal_busy             : out std_logic_vector(0 downto 0);                      -- rx_cal_busy
      rx_cdr_refclk0          : in  std_logic                     := 'X';              -- clk
      rx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_digitalreset
      rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- rx_digitalreset_stat
      rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtodata
      rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtoref
      rx_parallel_data        : out std_logic_vector(63 downto 0);                     -- rx_parallel_data
      rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_serial_data
      tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_analogreset
      tx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- tx_analogreset_stat
      tx_cal_busy             : out std_logic_vector(0 downto 0);                      -- tx_cal_busy
      tx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_digitalreset
      tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- tx_digitalreset_stat
      tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X');  -- tx_parallel_data
      tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_serial_data          : out std_logic_vector(0 downto 0);                      -- tx_serial_data
      unused_rx_parallel_data : out std_logic_vector(15 downto 0);                     -- unused_rx_parallel_data
      unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')   -- unused_tx_parallel_data
      );
  end component;


  component LH_ATX25G8Above is
    port(
      gxt_input_from_blw_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;

  component LH_ATX25G8Main is
    port(
      gxt_output_to_abv_atx : out std_logic;                                         -- clk
      gxt_output_to_blw_atx : out std_logic;                                         -- clk
      pll_cal_busy          : out std_logic;                                         -- pll_cal_busy
      pll_locked            : out std_logic;                                         -- pll_locked
      pll_refclk0           : in  std_logic                     := 'X';              -- clk
      reconfig_write0       : in  std_logic                     := 'X';              -- write
      reconfig_read0        : in  std_logic                     := 'X';              -- read
      reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0    : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0 : out std_logic;                                         -- waitrequest
      reconfig_clk0         : in  std_logic                     := 'X';              -- clk
      reconfig_reset0       : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt     : out std_logic                                          -- clk
      );
  end component;

  component LH_ATX25G8Below is
    port(
      gxt_input_from_abv_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;

  component LH_PHYGT28G0_x1 is
    port(
      reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- write
      reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- read
      reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata       : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest    : out std_logic_vector(0 downto 0);                      -- waitrequest
      reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- reset
      rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_analogreset
      rx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- rx_analogreset_stat
      rx_cal_busy             : out std_logic_vector(0 downto 0);                      -- rx_cal_busy
      rx_cdr_refclk0          : in  std_logic                     := 'X';              -- clk
      rx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_digitalreset
      rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- rx_digitalreset_stat
      rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtodata
      rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtoref
      rx_parallel_data        : out std_logic_vector(63 downto 0);                     -- rx_parallel_data
      rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_serial_data
      tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_analogreset
      tx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- tx_analogreset_stat
      tx_cal_busy             : out std_logic_vector(0 downto 0);                      -- tx_cal_busy
      tx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_digitalreset
      tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- tx_digitalreset_stat
      tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X');  -- tx_parallel_data
      tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_serial_data          : out std_logic_vector(0 downto 0);                      -- tx_serial_data
      unused_rx_parallel_data : out std_logic_vector(15 downto 0);                     -- unused_rx_parallel_data
      unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')   -- unused_tx_parallel_data
      );
  end component;


  component LH_ATX28G0Above is
    port(
      gxt_input_from_blw_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;

  component LH_ATX28G0Main is
    port(
      gxt_output_to_abv_atx : out std_logic;                                         -- clk
      gxt_output_to_blw_atx : out std_logic;                                         -- clk
      pll_cal_busy          : out std_logic;                                         -- pll_cal_busy
      pll_locked            : out std_logic;                                         -- pll_locked
      pll_refclk0           : in  std_logic                     := 'X';              -- clk
      reconfig_write0       : in  std_logic                     := 'X';              -- write
      reconfig_read0        : in  std_logic                     := 'X';              -- read
      reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0    : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0 : out std_logic;                                         -- waitrequest
      reconfig_clk0         : in  std_logic                     := 'X';              -- clk
      reconfig_reset0       : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt     : out std_logic                                          -- clk
      );
  end component;

  component LH_ATX28G0Below is
    port(
      gxt_input_from_abv_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;
  
  component LH_PHYGT28G3_x1 is
    port(
      reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- write
      reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- read
      reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata       : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest    : out std_logic_vector(0 downto 0);                      -- waitrequest
      reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- reset
      rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_analogreset
      rx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- rx_analogreset_stat
      rx_cal_busy             : out std_logic_vector(0 downto 0);                      -- rx_cal_busy
      rx_cdr_refclk0          : in  std_logic                     := 'X';              -- clk
      rx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_digitalreset
      rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- rx_digitalreset_stat
      rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtodata
      rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtoref
      rx_parallel_data        : out std_logic_vector(63 downto 0);                     -- rx_parallel_data
      rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_serial_data
      tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_analogreset
      tx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- tx_analogreset_stat
      tx_cal_busy             : out std_logic_vector(0 downto 0);                      -- tx_cal_busy
      tx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_digitalreset
      tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- tx_digitalreset_stat
      tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X');  -- tx_parallel_data
      tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_serial_data          : out std_logic_vector(0 downto 0);                      -- tx_serial_data
      unused_rx_parallel_data : out std_logic_vector(15 downto 0);                     -- unused_rx_parallel_data
      unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')   -- unused_tx_parallel_data
      );
  end component;


  component LH_ATX28G3Above is
    port(
      gxt_input_from_blw_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;

  component LH_ATX28G3Main is
    port(
      gxt_output_to_abv_atx : out std_logic;                                         -- clk
      gxt_output_to_blw_atx : out std_logic;                                         -- clk
      pll_cal_busy          : out std_logic;                                         -- pll_cal_busy
      pll_locked            : out std_logic;                                         -- pll_locked
      pll_refclk0           : in  std_logic                     := 'X';              -- clk
      reconfig_write0       : in  std_logic                     := 'X';              -- write
      reconfig_read0        : in  std_logic                     := 'X';              -- read
      reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0    : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0 : out std_logic;                                         -- waitrequest
      reconfig_clk0         : in  std_logic                     := 'X';              -- clk
      reconfig_reset0       : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt     : out std_logic                                          -- clk
      );
  end component;

  component LH_ATX28G3Below is
    port(
      gxt_input_from_abv_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;  
  
  ----------------------------
  component LH_PHYGTUSR0_x1 is
    port(
      reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- write
      reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- read
      reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata       : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest    : out std_logic_vector(0 downto 0);                      -- waitrequest
      reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- reset
      rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_analogreset
      rx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- rx_analogreset_stat
      rx_cal_busy             : out std_logic_vector(0 downto 0);                      -- rx_cal_busy
      rx_cdr_refclk0          : in  std_logic                     := 'X';              -- clk
      rx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_digitalreset
      rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- rx_digitalreset_stat
      rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtodata
      rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtoref
      rx_parallel_data        : out std_logic_vector(63 downto 0);                     -- rx_parallel_data
      rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_serial_data
      tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_analogreset
      tx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- tx_analogreset_stat
      tx_cal_busy             : out std_logic_vector(0 downto 0);                      -- tx_cal_busy
      tx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_digitalreset
      tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- tx_digitalreset_stat
      tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X');  -- tx_parallel_data
      tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_serial_data          : out std_logic_vector(0 downto 0);                      -- tx_serial_data
      unused_rx_parallel_data : out std_logic_vector(15 downto 0);                     -- unused_rx_parallel_data
      unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')   -- unused_tx_parallel_data
      );
  end component;


  component LH_ATXUSR0Above is
    port(
      gxt_input_from_blw_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;

  component LH_ATXUSR0Main is
    port(
      gxt_output_to_abv_atx : out std_logic;                                         -- clk
      gxt_output_to_blw_atx : out std_logic;                                         -- clk
      pll_cal_busy          : out std_logic;                                         -- pll_cal_busy
      pll_locked            : out std_logic;                                         -- pll_locked
      pll_refclk0           : in  std_logic                     := 'X';              -- clk
      reconfig_write0       : in  std_logic                     := 'X';              -- write
      reconfig_read0        : in  std_logic                     := 'X';              -- read
      reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0    : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0 : out std_logic;                                         -- waitrequest
      reconfig_clk0         : in  std_logic                     := 'X';              -- clk
      reconfig_reset0       : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt     : out std_logic                                          -- clk
      );
  end component;

  component LH_ATXUSR0Below is
    port(
      gxt_input_from_abv_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;
  
    ----------------------------
  component LH_PHYGTUSR1_x1 is
    port(
      reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- write
      reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- read
      reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata       : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest    : out std_logic_vector(0 downto 0);                      -- waitrequest
      reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- reset
      rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_analogreset
      rx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- rx_analogreset_stat
      rx_cal_busy             : out std_logic_vector(0 downto 0);                      -- rx_cal_busy
      rx_cdr_refclk0          : in  std_logic                     := 'X';              -- clk
      rx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_digitalreset
      rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- rx_digitalreset_stat
      rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtodata
      rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                      -- rx_is_lockedtoref
      rx_parallel_data        : out std_logic_vector(63 downto 0);                     -- rx_parallel_data
      rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- rx_serial_data
      tx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_analogreset
      tx_analogreset_stat     : out std_logic_vector(0 downto 0);                      -- tx_analogreset_stat
      tx_cal_busy             : out std_logic_vector(0 downto 0);                      -- tx_cal_busy
      tx_clkout               : out std_logic_vector(0 downto 0);                      -- clk
      tx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- tx_digitalreset
      tx_digitalreset_stat    : out std_logic_vector(0 downto 0);                      -- tx_digitalreset_stat
      tx_parallel_data        : in  std_logic_vector(63 downto 0) := (others => 'X');  -- tx_parallel_data
      tx_serial_clk0          : in  std_logic_vector(0 downto 0)  := (others => 'X');  -- clk
      tx_serial_data          : out std_logic_vector(0 downto 0);                      -- tx_serial_data
      unused_rx_parallel_data : out std_logic_vector(15 downto 0);                     -- unused_rx_parallel_data
      unused_tx_parallel_data : in  std_logic_vector(15 downto 0) := (others => 'X')   -- unused_tx_parallel_data
      );
  end component;


  component LH_ATXUSR1Above is
    port(
      gxt_input_from_blw_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;

  component LH_ATXUSR1Main is
    port(
      gxt_output_to_abv_atx : out std_logic;                                         -- clk
      gxt_output_to_blw_atx : out std_logic;                                         -- clk
      pll_cal_busy          : out std_logic;                                         -- pll_cal_busy
      pll_locked            : out std_logic;                                         -- pll_locked
      pll_refclk0           : in  std_logic                     := 'X';              -- clk
      reconfig_write0       : in  std_logic                     := 'X';              -- write
      reconfig_read0        : in  std_logic                     := 'X';              -- read
      reconfig_address0     : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0   : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0    : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0 : out std_logic;                                         -- waitrequest
      reconfig_clk0         : in  std_logic                     := 'X';              -- clk
      reconfig_reset0       : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt     : out std_logic                                          -- clk
      );
  end component;

  component LH_ATXUSR1Below is
    port(
      gxt_input_from_abv_atx : in  std_logic                     := 'X';              -- clk 
      pll_cal_busy           : out std_logic;                                         -- pll_cal_busy
      pll_locked             : out std_logic;                                         -- pll_locked
      pll_refclk0            : in  std_logic                     := 'X';              -- clk
      reconfig_write0        : in  std_logic                     := 'X';              -- write
      reconfig_read0         : in  std_logic                     := 'X';              -- read
      reconfig_address0      : in  std_logic_vector(10 downto 0) := (others => 'X');  -- address
      reconfig_writedata0    : in  std_logic_vector(31 downto 0) := (others => 'X');  -- writedata
      reconfig_readdata0     : out std_logic_vector(31 downto 0);                     -- readdata
      reconfig_waitrequest0  : out std_logic;                                         -- waitrequest
      reconfig_clk0          : in  std_logic                     := 'X';              -- clk
      reconfig_reset0        : in  std_logic                     := 'X';              -- reset
      tx_serial_clk_gxt      : out std_logic                                          -- clk
      );
  end component;

  component Reset is
    port(
      clock                : in  std_logic                    := '0';              --                clock.clk
      pll_locked           : in  std_logic_vector(0 downto 0) := (others => '0');  --           pll_locked.pll_locked
      pll_select           : in  std_logic_vector(0 downto 0) := (others => '0');  --           pll_select.pll_select
      reset                : in  std_logic                    := '0';              --                reset.reset
      rx_analogreset       : out std_logic_vector(0 downto 0);                     --       rx_analogreset.rx_analogreset
      rx_analogreset_stat  : in  std_logic_vector(0 downto 0) := (others => '0');  --  rx_analogreset_stat.rx_analogreset_stat
      rx_cal_busy          : in  std_logic_vector(0 downto 0) := (others => '0');  --          rx_cal_busy.rx_cal_busy
      rx_digitalreset      : out std_logic_vector(0 downto 0);                     --      rx_digitalreset.rx_digitalreset
      rx_digitalreset_stat : in  std_logic_vector(0 downto 0) := (others => '0');  -- rx_digitalreset_stat.rx_digitalreset_stat
      rx_is_lockedtodata   : in  std_logic_vector(0 downto 0) := (others => '0');  --   rx_is_lockedtodata.rx_is_lockedtodata
      rx_ready             : out std_logic_vector(0 downto 0);                     --             rx_ready.rx_ready
      tx_analogreset       : out std_logic_vector(0 downto 0);                     --       tx_analogreset.tx_analogreset
      tx_analogreset_stat  : in  std_logic_vector(0 downto 0) := (others => '0');  --  tx_analogreset_stat.tx_analogreset_stat
      tx_cal_busy          : in  std_logic_vector(0 downto 0) := (others => '0');  --          tx_cal_busy.tx_cal_busy
      tx_digitalreset      : out std_logic_vector(0 downto 0);                     --      tx_digitalreset.tx_digitalreset
      tx_digitalreset_stat : in  std_logic_vector(0 downto 0) := (others => '0');  -- tx_digitalreset_stat.tx_digitalreset_stat
      tx_ready             : out std_logic_vector(0 downto 0)                      --             tx_ready.tx_ready
      );
  end component;


  component DataMux64 is
    port(
      Reset                      : in  std_logic;
      rx_parallel_datain         : in  std_logic_vector(63 downto 0) := (others => '0');
      rx_clk                     : in  std_logic                     := '0';
      tx_parallel_dataout        : out std_logic_vector(63 downto 0) := (others => '0');
      tx_clk                     : in  std_logic                     := '0';
      Traffic_Tx_parallel_datain : in  std_logic_vector(63 downto 0) := (others => '0')
      );
  end component;



begin

--xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
-- Instance components here
--xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx


--###########################################
-- Above Channels
--###########################################

  AbovePHY : for i in 0 to NumAboveChannels-1 generate

    Gen_PHY28G3 : if Rate = "28G3" generate
      PHY : LH_PHYGT28G3_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => abv_rx_analogreset(i downto i),
          rx_analogreset_stat     => abv_rx_analogreset_stat(i downto i),
          rx_cal_busy             => abv_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => abv_rx_clkout(i downto i),
          rx_coreclkin            => abv_rx_clkout(i downto i),
          rx_digitalreset         => abv_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => abv_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => abv_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => abv_rx_parallel_data64(i),
          rx_serial_data          => abv_rx_serial_data(i downto i),
          tx_analogreset          => abv_tx_analogreset(i downto i),
          tx_analogreset_stat     => abv_tx_analogreset_stat(i downto i),
          tx_cal_busy             => abv_tx_cal_busy(i downto i),
          tx_clkout               => abv_tx_clkout(i downto i),
          tx_coreclkin            => abv_tx_clkout(i downto i),
          tx_digitalreset         => abv_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => abv_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => abv_tx_parallel_data64(i),
          tx_serial_clk0          => abv_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => abv_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHY28G0 : if Rate = "28G0" generate
      PHY : LH_PHYGT28G0_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => abv_rx_analogreset(i downto i),
          rx_analogreset_stat     => abv_rx_analogreset_stat(i downto i),
          rx_cal_busy             => abv_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => abv_rx_clkout(i downto i),
          rx_coreclkin            => abv_rx_clkout(i downto i),
          rx_digitalreset         => abv_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => abv_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => abv_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => abv_rx_parallel_data64(i),
          rx_serial_data          => abv_rx_serial_data(i downto i),
          tx_analogreset          => abv_tx_analogreset(i downto i),
          tx_analogreset_stat     => abv_tx_analogreset_stat(i downto i),
          tx_cal_busy             => abv_tx_cal_busy(i downto i),
          tx_clkout               => abv_tx_clkout(i downto i),
          tx_coreclkin            => abv_tx_clkout(i downto i),
          tx_digitalreset         => abv_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => abv_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => abv_tx_parallel_data64(i),
          tx_serial_clk0          => abv_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => abv_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHY25G8 : if Rate = "25G8" generate
      PHY : LH_PHYGT25G8_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => abv_rx_analogreset(i downto i),
          rx_analogreset_stat     => abv_rx_analogreset_stat(i downto i),
          rx_cal_busy             => abv_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => abv_rx_clkout(i downto i),
          rx_coreclkin            => abv_rx_clkout(i downto i),
          rx_digitalreset         => abv_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => abv_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => abv_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => abv_rx_parallel_data64(i),
          rx_serial_data          => abv_rx_serial_data(i downto i),
          tx_analogreset          => abv_tx_analogreset(i downto i),
          tx_analogreset_stat     => abv_tx_analogreset_stat(i downto i),
          tx_cal_busy             => abv_tx_cal_busy(i downto i),
          tx_clkout               => abv_tx_clkout(i downto i),
          tx_coreclkin            => abv_tx_clkout(i downto i),
          tx_digitalreset         => abv_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => abv_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => abv_tx_parallel_data64(i),
          tx_serial_clk0          => abv_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => abv_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;

    Gen_PHY24G3 : if Rate = "24G3" generate
      PHY : LH_PHYGT24G3_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => abv_rx_analogreset(i downto i),
          rx_analogreset_stat     => abv_rx_analogreset_stat(i downto i),
          rx_cal_busy             => abv_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => abv_rx_clkout(i downto i),
          rx_coreclkin            => abv_rx_clkout(i downto i),
          rx_digitalreset         => abv_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => abv_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => abv_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => abv_rx_parallel_data64(i),
          rx_serial_data          => abv_rx_serial_data(i downto i),
          tx_analogreset          => abv_tx_analogreset(i downto i),
          tx_analogreset_stat     => abv_tx_analogreset_stat(i downto i),
          tx_cal_busy             => abv_tx_cal_busy(i downto i),
          tx_clkout               => abv_tx_clkout(i downto i),
          tx_coreclkin            => abv_tx_clkout(i downto i),
          tx_digitalreset         => abv_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => abv_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => abv_tx_parallel_data64(i),
          tx_serial_clk0          => abv_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => abv_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHYUSR0 : if Rate = "USR0" generate
      PHY : LH_PHYGTUSR0_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => abv_rx_analogreset(i downto i),
          rx_analogreset_stat     => abv_rx_analogreset_stat(i downto i),
          rx_cal_busy             => abv_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => abv_rx_clkout(i downto i),
          rx_coreclkin            => abv_rx_clkout(i downto i),
          rx_digitalreset         => abv_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => abv_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => abv_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => abv_rx_parallel_data64(i),
          rx_serial_data          => abv_rx_serial_data(i downto i),
          tx_analogreset          => abv_tx_analogreset(i downto i),
          tx_analogreset_stat     => abv_tx_analogreset_stat(i downto i),
          tx_cal_busy             => abv_tx_cal_busy(i downto i),
          tx_clkout               => abv_tx_clkout(i downto i),
          tx_coreclkin            => abv_tx_clkout(i downto i),
          tx_digitalreset         => abv_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => abv_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => abv_tx_parallel_data64(i),
          tx_serial_clk0          => abv_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => abv_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHYUSR1 : if Rate = "USR1" generate
      PHY : LH_PHYGTUSR1_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => abv_rx_analogreset(i downto i),
          rx_analogreset_stat     => abv_rx_analogreset_stat(i downto i),
          rx_cal_busy             => abv_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => abv_rx_clkout(i downto i),
          rx_coreclkin            => abv_rx_clkout(i downto i),
          rx_digitalreset         => abv_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => abv_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => abv_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => abv_rx_parallel_data64(i),
          rx_serial_data          => abv_rx_serial_data(i downto i),
          tx_analogreset          => abv_tx_analogreset(i downto i),
          tx_analogreset_stat     => abv_tx_analogreset_stat(i downto i),
          tx_cal_busy             => abv_tx_cal_busy(i downto i),
          tx_clkout               => abv_tx_clkout(i downto i),
          tx_coreclkin            => abv_tx_clkout(i downto i),
          tx_digitalreset         => abv_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => abv_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => abv_tx_parallel_data64(i),
          tx_serial_clk0          => abv_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => abv_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;        

    RST : Reset
      port map
      (
        clock                => clk_100(0),
        pll_locked           => main_pll_locked,  -- abv_pll_locked,
        pll_select           => (others => '0'),
        reset                => Reset_in(0),
        rx_analogreset       => abv_rx_analogreset(i downto i),
        rx_analogreset_stat  => abv_rx_analogreset_stat(i downto i),
        rx_cal_busy          => abv_rx_cal_busy(i downto i),
        rx_digitalreset      => abv_rx_digitalreset(i downto i),
        rx_digitalreset_stat => abv_rx_digitalreset_stat(i downto i),
        rx_is_lockedtodata   => abv_rx_is_lockedtodata(i downto i),
        rx_ready             => open,
        tx_analogreset       => abv_tx_analogreset(i downto i),
        tx_analogreset_stat  => abv_tx_analogreset_stat(i downto i),
        tx_cal_busy          => abv_tx_cal_busy(i downto i),
        tx_digitalreset      => abv_tx_digitalreset(i downto i),
        tx_digitalreset_stat => abv_tx_digitalreset_stat(i downto i),
        tx_ready             => open
        );

		Gen_Mux:if SIPatterns = TRUE generate 				
    	DataPathSel : DataMux64
    	  port map
    	  (
    	   Reset                      => abv_tx_digitalreset_stat(i),
    	   rx_parallel_datain         => abv_rx_parallel_data64(i),
    	   rx_clk                     => abv_rx_clkout(i),
    	   tx_parallel_dataout        => abv_tx_parallel_data64(i),
    	   tx_clk                     => abv_tx_clkout(i),
    	   Traffic_Tx_parallel_datain => x"BCBCBCBC" & x"BCBCBCBC"  -- just putting control characters on here for now.
    	   );
		end generate Gen_Mux;	        					        

  end generate;

--###########################################
-- Main Channels
--###########################################

  MainPHY : for i in 0 to NumMainChannels-1 generate

    Gen_PHY28G3 : if Rate = "28G3" generate
      PHY : LH_PHYGT28G3_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => main_rx_analogreset(i downto i),
          rx_analogreset_stat     => main_rx_analogreset_stat(i downto i),
          rx_cal_busy             => main_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => main_rx_clkout(i downto i),
          rx_coreclkin            => main_rx_clkout(i downto i),
          rx_digitalreset         => main_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => main_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => main_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => main_rx_parallel_data64(i),
          rx_serial_data          => main_rx_serial_data(i downto i),
          tx_analogreset          => main_tx_analogreset(i downto i),
          tx_analogreset_stat     => main_tx_analogreset_stat(i downto i),
          tx_cal_busy             => main_tx_cal_busy(i downto i),
          tx_clkout               => main_tx_clkout(i downto i),
          tx_coreclkin            => main_tx_clkout(i downto i),
          tx_digitalreset         => main_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => main_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => main_tx_parallel_data64(i),
          tx_serial_clk0          => main_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => main_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHY28G0 : if Rate = "28G0" generate
      PHY : LH_PHYGT28G0_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => main_rx_analogreset(i downto i),
          rx_analogreset_stat     => main_rx_analogreset_stat(i downto i),
          rx_cal_busy             => main_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => main_rx_clkout(i downto i),
          rx_coreclkin            => main_rx_clkout(i downto i),
          rx_digitalreset         => main_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => main_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => main_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => main_rx_parallel_data64(i),
          rx_serial_data          => main_rx_serial_data(i downto i),
          tx_analogreset          => main_tx_analogreset(i downto i),
          tx_analogreset_stat     => main_tx_analogreset_stat(i downto i),
          tx_cal_busy             => main_tx_cal_busy(i downto i),
          tx_clkout               => main_tx_clkout(i downto i),
          tx_coreclkin            => main_tx_clkout(i downto i),
          tx_digitalreset         => main_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => main_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => main_tx_parallel_data64(i),
          tx_serial_clk0          => main_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => main_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHY25G8 : if Rate = "25G8" generate
      PHY : LH_PHYGT25G8_x1
        port map
        (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => main_rx_analogreset(i downto i),
          rx_analogreset_stat     => main_rx_analogreset_stat(i downto i),
          rx_cal_busy             => main_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => main_rx_clkout(i downto i),
          rx_coreclkin            => main_rx_clkout(i downto i),
          rx_digitalreset         => main_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => main_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => main_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => main_rx_parallel_data64(i),
          rx_serial_data          => main_rx_serial_data(i downto i),
          tx_analogreset          => main_tx_analogreset(i downto i),
          tx_analogreset_stat     => main_tx_analogreset_stat(i downto i),
          tx_cal_busy             => main_tx_cal_busy(i downto i),
          tx_clkout               => main_tx_clkout(i downto i),
          tx_coreclkin            => main_tx_clkout(i downto i),
          tx_digitalreset         => main_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => main_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => main_tx_parallel_data64(i),
          tx_serial_clk0          => main_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => main_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;

    Gen_PHY24G3 : if Rate = "24G3" generate
      PHY : LH_PHYGT24G3_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => main_rx_analogreset(i downto i),
          rx_analogreset_stat     => main_rx_analogreset_stat(i downto i),
          rx_cal_busy             => main_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => main_rx_clkout(i downto i),
          rx_coreclkin            => main_rx_clkout(i downto i),
          rx_digitalreset         => main_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => main_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => main_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => main_rx_parallel_data64(i),
          rx_serial_data          => main_rx_serial_data(i downto i),
          tx_analogreset          => main_tx_analogreset(i downto i),
          tx_analogreset_stat     => main_tx_analogreset_stat(i downto i),
          tx_cal_busy             => main_tx_cal_busy(i downto i),
          tx_clkout               => main_tx_clkout(i downto i),
          tx_coreclkin            => main_tx_clkout(i downto i),
          tx_digitalreset         => main_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => main_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => main_tx_parallel_data64(i),
          tx_serial_clk0          => main_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => main_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHYUSR0 : if Rate = "USR0" generate
      PHY : LH_PHYGTUSR0_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => main_rx_analogreset(i downto i),
          rx_analogreset_stat     => main_rx_analogreset_stat(i downto i),
          rx_cal_busy             => main_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => main_rx_clkout(i downto i),
          rx_coreclkin            => main_rx_clkout(i downto i),
          rx_digitalreset         => main_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => main_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => main_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => main_rx_parallel_data64(i),
          rx_serial_data          => main_rx_serial_data(i downto i),
          tx_analogreset          => main_tx_analogreset(i downto i),
          tx_analogreset_stat     => main_tx_analogreset_stat(i downto i),
          tx_cal_busy             => main_tx_cal_busy(i downto i),
          tx_clkout               => main_tx_clkout(i downto i),
          tx_coreclkin            => main_tx_clkout(i downto i),
          tx_digitalreset         => main_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => main_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => main_tx_parallel_data64(i),
          tx_serial_clk0          => main_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => main_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHYUSR1 : if Rate = "USR1" generate
      PHY : LH_PHYGTUSR1_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => main_rx_analogreset(i downto i),
          rx_analogreset_stat     => main_rx_analogreset_stat(i downto i),
          rx_cal_busy             => main_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => main_rx_clkout(i downto i),
          rx_coreclkin            => main_rx_clkout(i downto i),
          rx_digitalreset         => main_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => main_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => main_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => main_rx_parallel_data64(i),
          rx_serial_data          => main_rx_serial_data(i downto i),
          tx_analogreset          => main_tx_analogreset(i downto i),
          tx_analogreset_stat     => main_tx_analogreset_stat(i downto i),
          tx_cal_busy             => main_tx_cal_busy(i downto i),
          tx_clkout               => main_tx_clkout(i downto i),
          tx_coreclkin            => main_tx_clkout(i downto i),
          tx_digitalreset         => main_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => main_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => main_tx_parallel_data64(i),
          tx_serial_clk0          => main_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => main_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;        

    RST : Reset
      port map
      (
        clock                => clk_100(0),
        pll_locked           => main_pll_locked,
        pll_select           => (others => '0'),
        reset                => Reset_in(0),
        rx_analogreset       => main_rx_analogreset(i downto i),
        rx_analogreset_stat  => main_rx_analogreset_stat(i downto i),
        rx_cal_busy          => main_rx_cal_busy(i downto i),
        rx_digitalreset      => main_rx_digitalreset(i downto i),
        rx_digitalreset_stat => main_rx_digitalreset_stat(i downto i),
        rx_is_lockedtodata   => main_rx_is_lockedtodata(i downto i),
        rx_ready             => open,
        tx_analogreset       => main_tx_analogreset(i downto i),
        tx_analogreset_stat  => main_tx_analogreset_stat(i downto i),
        tx_cal_busy          => main_tx_cal_busy(i downto i),
        tx_digitalreset      => main_tx_digitalreset(i downto i),
        tx_digitalreset_stat => main_tx_digitalreset_stat(i downto i),
        tx_ready             => open
        );

		Gen_Mux:if SIPatterns = TRUE generate 				
    	DataPathSel : DataMux64
    	  port map
    	  (
    	   Reset                      => main_tx_digitalreset_stat(i),
    	   rx_parallel_datain         => main_rx_parallel_data64(i),
    	   rx_clk                     => main_rx_clkout(i),
    	   tx_parallel_dataout        => main_tx_parallel_data64(i),
    	   tx_clk                     => main_tx_clkout(i),
    	   Traffic_Tx_parallel_datain => x"BCBCBCBC" & x"BCBCBCBC"  -- just putting control characters on here for now.
    	   );
		end generate Gen_Mux;	        					        
		
  end generate;



--###########################################
-- Below Channels
--###########################################

  BelowPHY : for i in 0 to NumBelowChannels-1 generate

    Gen_PHY28G3 : if Rate = "28G3" generate
      PHY : LH_PHYGT28G3_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => blw_rx_analogreset(i downto i),
          rx_analogreset_stat     => blw_rx_analogreset_stat(i downto i),
          rx_cal_busy             => blw_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => blw_rx_clkout(i downto i),
          rx_coreclkin            => blw_rx_clkout(i downto i),
          rx_digitalreset         => blw_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => blw_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => blw_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => blw_rx_parallel_data64(i),
          rx_serial_data          => blw_rx_serial_data(i downto i),
          tx_analogreset          => blw_tx_analogreset(i downto i),
          tx_analogreset_stat     => blw_tx_analogreset_stat(i downto i),
          tx_cal_busy             => blw_tx_cal_busy(i downto i),
          tx_clkout               => blw_tx_clkout(i downto i),
          tx_coreclkin            => blw_tx_clkout(i downto i),
          tx_digitalreset         => blw_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => blw_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => blw_tx_parallel_data64(i),
          tx_serial_clk0          => blw_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => blw_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHY28G0 : if Rate = "28G0" generate
      PHY : LH_PHYGT28G0_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => blw_rx_analogreset(i downto i),
          rx_analogreset_stat     => blw_rx_analogreset_stat(i downto i),
          rx_cal_busy             => blw_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => blw_rx_clkout(i downto i),
          rx_coreclkin            => blw_rx_clkout(i downto i),
          rx_digitalreset         => blw_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => blw_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => blw_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => blw_rx_parallel_data64(i),
          rx_serial_data          => blw_rx_serial_data(i downto i),
          tx_analogreset          => blw_tx_analogreset(i downto i),
          tx_analogreset_stat     => blw_tx_analogreset_stat(i downto i),
          tx_cal_busy             => blw_tx_cal_busy(i downto i),
          tx_clkout               => blw_tx_clkout(i downto i),
          tx_coreclkin            => blw_tx_clkout(i downto i),
          tx_digitalreset         => blw_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => blw_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => blw_tx_parallel_data64(i),
          tx_serial_clk0          => blw_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => blw_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHY25G8 : if Rate = "25G8" generate
      PHY : LH_PHYGT25G8_x1
        port map
        (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => blw_rx_analogreset(i downto i),
          rx_analogreset_stat     => blw_rx_analogreset_stat(i downto i),
          rx_cal_busy             => blw_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => blw_rx_clkout(i downto i),
          rx_coreclkin            => blw_rx_clkout(i downto i),
          rx_digitalreset         => blw_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => blw_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => blw_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => blw_rx_parallel_data64(i),
          rx_serial_data          => blw_rx_serial_data(i downto i),
          tx_analogreset          => blw_tx_analogreset(i downto i),
          tx_analogreset_stat     => blw_tx_analogreset_stat(i downto i),
          tx_cal_busy             => blw_tx_cal_busy(i downto i),
          tx_clkout               => blw_tx_clkout(i downto i),
          tx_coreclkin            => blw_tx_clkout(i downto i),
          tx_digitalreset         => blw_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => blw_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => blw_tx_parallel_data64(i),
          tx_serial_clk0          => blw_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => blw_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;

    Gen_PHY24G3 : if Rate = "24G3" generate
      PHY : LH_PHYGT24G3_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => blw_rx_analogreset(i downto i),
          rx_analogreset_stat     => blw_rx_analogreset_stat(i downto i),
          rx_cal_busy             => blw_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => blw_rx_clkout(i downto i),
          rx_coreclkin            => blw_rx_clkout(i downto i),
          rx_digitalreset         => blw_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => blw_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => blw_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => blw_rx_parallel_data64(i),
          rx_serial_data          => blw_rx_serial_data(i downto i),
          tx_analogreset          => blw_tx_analogreset(i downto i),
          tx_analogreset_stat     => blw_tx_analogreset_stat(i downto i),
          tx_cal_busy             => blw_tx_cal_busy(i downto i),
          tx_clkout               => blw_tx_clkout(i downto i),
          tx_coreclkin            => blw_tx_clkout(i downto i),
          tx_digitalreset         => blw_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => blw_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => blw_tx_parallel_data64(i),
          tx_serial_clk0          => blw_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => blw_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;
    
    Gen_PHYUSR0 : if Rate = "USR0" generate
      PHY : LH_PHYGTUSR0_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => blw_rx_analogreset(i downto i),
          rx_analogreset_stat     => blw_rx_analogreset_stat(i downto i),
          rx_cal_busy             => blw_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => blw_rx_clkout(i downto i),
          rx_coreclkin            => blw_rx_clkout(i downto i),
          rx_digitalreset         => blw_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => blw_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => blw_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => blw_rx_parallel_data64(i),
          rx_serial_data          => blw_rx_serial_data(i downto i),
          tx_analogreset          => blw_tx_analogreset(i downto i),
          tx_analogreset_stat     => blw_tx_analogreset_stat(i downto i),
          tx_cal_busy             => blw_tx_cal_busy(i downto i),
          tx_clkout               => blw_tx_clkout(i downto i),
          tx_coreclkin            => blw_tx_clkout(i downto i),
          tx_digitalreset         => blw_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => blw_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => blw_tx_parallel_data64(i),
          tx_serial_clk0          => blw_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => blw_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;    
    
    Gen_PHYUSR1 : if Rate = "USR1" generate
      PHY : LH_PHYGTUSR1_x1
        port map (
          reconfig_write          => (others => '0'),
          reconfig_read           => (others => '0'),
          reconfig_address        => (others => '0'),
          reconfig_writedata      => (others => '0'),
          reconfig_readdata       => open,
          reconfig_waitrequest    => open,
          reconfig_clk            => clk_100,
          reconfig_reset          => Reset_in,
          rx_analogreset          => blw_rx_analogreset(i downto i),
          rx_analogreset_stat     => blw_rx_analogreset_stat(i downto i),
          rx_cal_busy             => blw_rx_cal_busy(i downto i),
          rx_cdr_refclk0          => refclk,
          rx_clkout               => blw_rx_clkout(i downto i),
          rx_coreclkin            => blw_rx_clkout(i downto i),
          rx_digitalreset         => blw_rx_digitalreset(i downto i),
          rx_digitalreset_stat    => blw_rx_digitalreset_stat(i downto i),
          rx_is_lockedtodata      => blw_rx_is_lockedtodata(i downto i),
          rx_is_lockedtoref       => open,
          rx_parallel_data        => blw_rx_parallel_data64(i),
          rx_serial_data          => blw_rx_serial_data(i downto i),
          tx_analogreset          => blw_tx_analogreset(i downto i),
          tx_analogreset_stat     => blw_tx_analogreset_stat(i downto i),
          tx_cal_busy             => blw_tx_cal_busy(i downto i),
          tx_clkout               => blw_tx_clkout(i downto i),
          tx_coreclkin            => blw_tx_clkout(i downto i),
          tx_digitalreset         => blw_tx_digitalreset(i downto i),
          tx_digitalreset_stat    => blw_tx_digitalreset_stat(i downto i),
          tx_parallel_data        => blw_tx_parallel_data64(i),
          tx_serial_clk0          => blw_tx_serial_clk_gxt(0 downto 0),
          tx_serial_data          => blw_tx_serial_data(i downto i),
          unused_rx_parallel_data => open,
          unused_tx_parallel_data => (others => '0')
          );
    end generate;        

    RST : Reset
      port map
      (
        clock                => clk_100(0),
        pll_locked           => main_pll_locked,  -- blw_pll_locked,
        pll_select           => (others => '0'),
        reset                => Reset_in(0),
        rx_analogreset       => blw_rx_analogreset(i downto i),
        rx_analogreset_stat  => blw_rx_analogreset_stat(i downto i),
        rx_cal_busy          => blw_rx_cal_busy(i downto i),
        rx_digitalreset      => blw_rx_digitalreset(i downto i),
        rx_digitalreset_stat => blw_rx_digitalreset_stat(i downto i),
        rx_is_lockedtodata   => blw_rx_is_lockedtodata(i downto i),
        rx_ready             => open,
        tx_analogreset       => blw_tx_analogreset(i downto i),
        tx_analogreset_stat  => blw_tx_analogreset_stat(i downto i),
        tx_cal_busy          => blw_tx_cal_busy(i downto i),
        tx_digitalreset      => blw_tx_digitalreset(i downto i),
        tx_digitalreset_stat => blw_tx_digitalreset_stat(i downto i),
        tx_ready             => open
        );

		Gen_Mux:if SIPatterns = TRUE generate 				
    	DataPathSel : DataMux64
    	  port map
    	  (
    	   Reset                      => blw_tx_digitalreset_stat(i),
    	   rx_parallel_datain         => blw_rx_parallel_data64(i),
    	   rx_clk                     => blw_rx_clkout(i),
    	   tx_parallel_dataout        => blw_tx_parallel_data64(i),
    	   tx_clk                     => blw_tx_clkout(i),
    	   Traffic_Tx_parallel_datain => x"BCBCBCBC" & x"BCBCBCBC"  -- just putting control characters on here for now.
    	   );
		end generate Gen_Mux;	        					        

  end generate;
  
--###########################################
-- Above ATX PLLs
--###########################################  

  Gen_AboveATX : if NumAboveChannels > 0 generate
  
    Gen_ATX28G3 : if Rate = "28G3" generate
      AboveATX : LH_ATX28G3Above
        port map
        (
          gxt_input_from_blw_atx => gxt_output_to_abv_atx,
          pll_cal_busy           => open,
          pll_locked             => abv_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => abv_tx_serial_clk_gxt(0)
          );
    end generate;
      
    Gen_ATX28G0 : if Rate = "28G0" generate
      AboveATX : LH_ATX28G0Above
        port map
        (
          gxt_input_from_blw_atx => gxt_output_to_abv_atx,
          pll_cal_busy           => open,
          pll_locked             => abv_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => abv_tx_serial_clk_gxt(0)
          );
    end generate;
      
    Gen_ATX25G8 : if Rate = "25G8" generate
      AboveATX : LH_ATX25G8Above
        port map
        (
          gxt_input_from_blw_atx => gxt_output_to_abv_atx,
          pll_cal_busy           => open,
          pll_locked             => abv_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => abv_tx_serial_clk_gxt(0)
          );
    end generate;
    
    Gen_ATX24G3 : if Rate = "24G3" generate
      AboveATX : LH_ATX24G3Above
        port map
        (
          gxt_input_from_blw_atx => gxt_output_to_abv_atx,
          pll_cal_busy           => open,
          pll_locked             => abv_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => abv_tx_serial_clk_gxt(0)
          );
    end generate;
    
    Gen_ATXUSR0 : if Rate = "USR0" generate
      AboveATX : LH_ATXUSR0Above
        port map
        (
          gxt_input_from_blw_atx => gxt_output_to_abv_atx,
          pll_cal_busy           => open,
          pll_locked             => abv_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => abv_tx_serial_clk_gxt(0)
          );
    end generate;
    
    Gen_ATXUSR1 : if Rate = "USR1" generate
      AboveATX : LH_ATXUSR1Above
        port map
        (
          gxt_input_from_blw_atx => gxt_output_to_abv_atx,
          pll_cal_busy           => open,
          pll_locked             => abv_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => abv_tx_serial_clk_gxt(0)
          );
    end generate;    
        
  end generate;
  
--###########################################
-- Main ATX PLLs
--###########################################   

  Gen_MainATX : if NumMainChannels > 0 generate
  
    Gen_ATX28G3 : if Rate = "28G3" generate
      MainATX : LH_ATX28G3Main
        port map
        (
          gxt_output_to_abv_atx => gxt_output_to_abv_atx,
          gxt_output_to_blw_atx => gxt_output_to_blw_atx,
          pll_cal_busy          => open,
          pll_locked            => main_pll_locked(0),
          pll_refclk0           => refclk,
          reconfig_write0       => '0',
          reconfig_read0        => '0',
          reconfig_address0     => (others => '0'),
          reconfig_writedata0   => (others => '0'),
          reconfig_readdata0    => open,
          reconfig_waitrequest0 => open,
          reconfig_clk0         => clk_100(0),
          reconfig_reset0       => Reset_in(0),
          tx_serial_clk_gxt     => main_tx_serial_clk_gxt(0)
          );
    end generate;
      
    Gen_ATX28G0 : if Rate = "28G0" generate
      MainATX : LH_ATX28G0Main
        port map
        (
          gxt_output_to_abv_atx => gxt_output_to_abv_atx,
          gxt_output_to_blw_atx => gxt_output_to_blw_atx,
          pll_cal_busy          => open,
          pll_locked            => main_pll_locked(0),
          pll_refclk0           => refclk,
          reconfig_write0       => '0',
          reconfig_read0        => '0',
          reconfig_address0     => (others => '0'),
          reconfig_writedata0   => (others => '0'),
          reconfig_readdata0    => open,
          reconfig_waitrequest0 => open,
          reconfig_clk0         => clk_100(0),
          reconfig_reset0       => Reset_in(0),
          tx_serial_clk_gxt     => main_tx_serial_clk_gxt(0)
          );
    end generate;
      
    Gen_ATX25G8 : if Rate = "25G8" generate
      MainATX : LH_ATX25G8Main
        port map
        (
          gxt_output_to_abv_atx => gxt_output_to_abv_atx,
          gxt_output_to_blw_atx => gxt_output_to_blw_atx,
          pll_cal_busy          => open,
          pll_locked            => main_pll_locked(0),
          pll_refclk0           => refclk,
          reconfig_write0       => '0',
          reconfig_read0        => '0',
          reconfig_address0     => (others => '0'),
          reconfig_writedata0   => (others => '0'),
          reconfig_readdata0    => open,
          reconfig_waitrequest0 => open,
          reconfig_clk0         => clk_100(0),
          reconfig_reset0       => Reset_in(0),
          tx_serial_clk_gxt     => main_tx_serial_clk_gxt(0)
          );
    end generate;
    
    Gen_ATX24G3 : if Rate = "24G3" generate
      MainATX : LH_ATX24G3Main
        port map
        (
          gxt_output_to_abv_atx => gxt_output_to_abv_atx,
          gxt_output_to_blw_atx => gxt_output_to_blw_atx,
          pll_cal_busy          => open,
          pll_locked            => main_pll_locked(0),
          pll_refclk0           => refclk,
          reconfig_write0       => '0',
          reconfig_read0        => '0',
          reconfig_address0     => (others => '0'),
          reconfig_writedata0   => (others => '0'),
          reconfig_readdata0    => open,
          reconfig_waitrequest0 => open,
          reconfig_clk0         => clk_100(0),
          reconfig_reset0       => Reset_in(0),
          tx_serial_clk_gxt     => main_tx_serial_clk_gxt(0)
          );
    end generate;
    
    Gen_ATXUSR0 : if Rate = "USR0" generate
      MainATX : LH_ATXUSR0Main
        port map
        (
          gxt_output_to_abv_atx => gxt_output_to_abv_atx,
          gxt_output_to_blw_atx => gxt_output_to_blw_atx,
          pll_cal_busy          => open,
          pll_locked            => main_pll_locked(0),
          pll_refclk0           => refclk,
          reconfig_write0       => '0',
          reconfig_read0        => '0',
          reconfig_address0     => (others => '0'),
          reconfig_writedata0   => (others => '0'),
          reconfig_readdata0    => open,
          reconfig_waitrequest0 => open,
          reconfig_clk0         => clk_100(0),
          reconfig_reset0       => Reset_in(0),
          tx_serial_clk_gxt     => main_tx_serial_clk_gxt(0)
          );
    end generate;    
    
    Gen_ATXUSR1 : if Rate = "USR1" generate
      MainATX : LH_ATXUSR1Main
        port map
        (
          gxt_output_to_abv_atx => gxt_output_to_abv_atx,
          gxt_output_to_blw_atx => gxt_output_to_blw_atx,
          pll_cal_busy          => open,
          pll_locked            => main_pll_locked(0),
          pll_refclk0           => refclk,
          reconfig_write0       => '0',
          reconfig_read0        => '0',
          reconfig_address0     => (others => '0'),
          reconfig_writedata0   => (others => '0'),
          reconfig_readdata0    => open,
          reconfig_waitrequest0 => open,
          reconfig_clk0         => clk_100(0),
          reconfig_reset0       => Reset_in(0),
          tx_serial_clk_gxt     => main_tx_serial_clk_gxt(0)
          );
    end generate;        
    
  end generate;

--###########################################
-- Below ATX PLLs
--########################################### 

  Gen_BelowATX : if NumBelowChannels > 0 generate
  
    Gen_ATX28G3 : if Rate = "28G3" generate
      BelowATX : LH_ATX28G3Below
        port map
        (
          gxt_input_from_abv_atx => gxt_output_to_blw_atx,
          pll_cal_busy           => open,
          pll_locked             => blw_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => blw_tx_serial_clk_gxt(0)
          );
    end generate;
      
    Gen_ATX28G0 : if Rate = "28G0" generate
      BelowATX : LH_ATX28G0Below
        port map
        (
          gxt_input_from_abv_atx => gxt_output_to_blw_atx,
          pll_cal_busy           => open,
          pll_locked             => blw_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => blw_tx_serial_clk_gxt(0)
          );
    end generate;
      
    Gen_ATX25G8 : if Rate = "25G8" generate
      BelowATX : LH_ATX25G8Below
        port map
        (
          gxt_input_from_abv_atx => gxt_output_to_blw_atx,
          pll_cal_busy           => open,
          pll_locked             => blw_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => blw_tx_serial_clk_gxt(0)
          );
    end generate;
    
    Gen_ATX24G3 : if Rate = "24G3" generate
      BelowATX : LH_ATX24G3Below
        port map
        (
          gxt_input_from_abv_atx => gxt_output_to_blw_atx,
          pll_cal_busy           => open,
          pll_locked             => blw_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => blw_tx_serial_clk_gxt(0)
          );
    end generate;
    
    Gen_ATXUSR0 : if Rate = "USR0" generate
      BelowATX : LH_ATXUSR0Below
        port map
        (
          gxt_input_from_abv_atx => gxt_output_to_blw_atx,
          pll_cal_busy           => open,
          pll_locked             => blw_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => blw_tx_serial_clk_gxt(0)
          );
    end generate;
    
    Gen_ATXUSR1 : if Rate = "USR1" generate
      BelowATX : LH_ATXUSR1Below
        port map
        (
          gxt_input_from_abv_atx => gxt_output_to_blw_atx,
          pll_cal_busy           => open,
          pll_locked             => blw_pll_locked(0),
          pll_refclk0            => refclk,
          reconfig_write0        => '0',
          reconfig_read0         => '0',
          reconfig_address0      => (others => '0'),
          reconfig_writedata0    => (others => '0'),
          reconfig_readdata0     => open,
          reconfig_waitrequest0  => open,
          reconfig_clk0          => clk_100(0),
          reconfig_reset0        => Reset_in(0),
          tx_serial_clk_gxt      => blw_tx_serial_clk_gxt(0)
          );
    end generate;    
        
  end generate;


end rtl;


