--######################################################################################################
-- FILE          : LH_Rx[n]_Wrap
-- RELATED FILES :
-- DESCRIPTION   : This file is a wrapper file for the Stratix 10 H-Tile PHY Receiver Only
--               : N PHYs and reset controllers are generated. 
--               : Multiple datarates are supported at compile time rather than dynamic reconfiguration
--               :
-- AUTHOR        : James Murray 
-- DEPARTMENT    : European Regional Application Engineering
-- COMPANY       : Intel PSG
--######################################################################################################

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;


entity LH_Rx0_Wrap is
	generic(	NumChannels:integer:=0;
						Rate:string:="10G3");
	port
	(
		refclk						: in std_logic;
		rx_serial_data		: in  std_logic_vector(NumChannels-1 downto 0)   := (others => '0');
		rxclkout               : out std_logic_vector(NumChannels-1 downto 0);                     -- clk		
		clk_100						: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in					: in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
	);
end entity LH_Rx0_Wrap;

architecture rtl of LH_Rx0_Wrap is


-- Parallel CLK Signals	
	signal rx_clkout				: std_logic_vector(NumChannels-1 downto 0);                   
	
-- Reset Signals
	signal rx_analogreset     	: std_logic_vector(NumChannels-1 downto 0);                   
	signal rx_analogreset_stat 	: std_logic_vector(NumChannels-1 downto 0);                   	
	signal rx_digitalreset    	: std_logic_vector(NumChannels-1 downto 0);                   
	signal rx_digitalreset_stat	: std_logic_vector(NumChannels-1 downto 0);                   	
	signal rx_is_lockedtodata 	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_is_lockedtoref 		: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_set_lockedtodata	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_set_lockedtoref 	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	signal rx_cal_busy        	: std_logic_vector(NumChannels-1 downto 0) := (others => '0');
	
	type rx_parallel_data_array is array (NumChannels-1 downto 0) of std_logic_vector(63 downto 0);  
	signal rx_parallel_data : rx_parallel_data_array;

	type rx_parallel_data128_array is array (NumChannels-1 downto 0) of std_logic_vector(127 downto 0);  
	signal rx_parallel_data128 : rx_parallel_data128_array; 	

	type rx_parallel_data64_array is array (NumChannels-1 downto 0) of std_logic_vector(63 downto 0);  
	signal rx_parallel_data64 : rx_parallel_data64_array; 	
	 	
component LH_PHYRx9G8_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRx10G1_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRx10G3_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRx11G3_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRx12G5_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRx17G4_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRxUSR0_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRxUSR1_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRxUSR2_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;

component LH_PHYRxUSR3_x1 is
	PORT(
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest
		reconfig_clk            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		reconfig_reset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- reset
		rx_analogreset          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_analogreset
		rx_analogreset_stat     : out std_logic_vector(0 downto 0);                     -- rx_analogreset_stat
		rx_cal_busy             : out std_logic_vector(0 downto 0);                     -- rx_cal_busy
		rx_cdr_refclk0          : in  std_logic                     := 'X';             -- clk
		rx_clkout               : out std_logic_vector(0 downto 0);                     -- clk
		rx_coreclkin            : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- clk
		rx_digitalreset         : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_digitalreset
		rx_digitalreset_stat    : out std_logic_vector(0 downto 0);                     -- rx_digitalreset_stat
		rx_is_lockedtodata      : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtodata
		rx_is_lockedtoref       : out std_logic_vector(0 downto 0);                     -- rx_is_lockedtoref
		rx_parallel_data        : out std_logic_vector(63 downto 0);                    -- rx_parallel_data
		rx_serial_data          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- rx_serial_data
		unused_rx_parallel_data : out std_logic_vector(15 downto 0)                    -- unused_rx_parallel_data
		);
end component;
  
component ResetRx is
	PORT(
		clock                : in  std_logic                    := '0';             --                clock.clk
		reset                : in  std_logic                    := '0';             --                reset.reset
		rx_analogreset       : out std_logic_vector(0 downto 0);                    --       rx_analogreset.rx_analogreset
		rx_analogreset_stat  : in  std_logic_vector(0 downto 0) := (others => '0'); --  rx_analogreset_stat.rx_analogreset_stat
		rx_cal_busy          : in  std_logic_vector(0 downto 0) := (others => '0'); --          rx_cal_busy.rx_cal_busy
		rx_digitalreset      : out std_logic_vector(0 downto 0);                    --      rx_digitalreset.rx_digitalreset
		rx_digitalreset_stat : in  std_logic_vector(0 downto 0) := (others => '0'); -- rx_digitalreset_stat.rx_digitalreset_stat
		rx_is_lockedtodata   : in  std_logic_vector(0 downto 0) := (others => '0'); --   rx_is_lockedtodata.rx_is_lockedtodata
		rx_ready             : out std_logic_vector(0 downto 0)                    --             rx_ready.rx_ready
		);
end component;


component DataMux64 is
	PORT(
		Reset								: in  std_logic;
		rx_parallel_datain  : in  std_logic_vector(63 downto 0)    := (others => '0');
		rx_clk							: in  std_logic := '0';
		tx_parallel_dataout : out std_logic_vector(63 downto 0)    := (others => '0');
		tx_clk							: in  std_logic := '0';
		Traffic_Tx_parallel_datain	: in  std_logic_vector(63 downto 0)    := (others => '0')
		);
end component;


                                                               
begin                                                                                                                                     
                                                           
--xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
-- Instance components here
--xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
	
CH: for i in 0 to NumChannels-1 generate 

	Gen_PHY9G8:if Rate = "9G8" generate 
			PHY: LH_PHYRx9G8_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHY9G8;		                             

	Gen_PHY10G1Rx:if Rate = "10G1" generate 
			PHY: LH_PHYRx10G1_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHY10G1Rx;		                             

	Gen_PHY10G3Rx:if Rate = "10G3" generate 
			PHY: LH_PHYRx10G3_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHY10G3Rx;		                             
				 
	Gen_PHY11G3:if Rate = "11G3" generate 
			PHY: LH_PHYRx11G3_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHY11G3;		  
			
	Gen_PHY12G5Rx:if Rate = "12G5" generate 
			PHY: LH_PHYRx12G5_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHY12G5Rx;		                             
			                           				 
	Gen_PHY17G4Rx:if Rate = "17G4" generate 
			PHY: LH_PHYRx17G4_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHY17G4Rx;	
			
	Gen_PHYUSR0Rx:if Rate = "USR0" generate 
			PHY: LH_PHYRxUSR0_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHYUSR0Rx;		
						
	Gen_PHYUSR1Rx:if Rate = "USR1" generate 
			PHY: LH_PHYRxUSR1_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHYUSR1Rx;		
			
	Gen_PHYUSR2Rx:if Rate = "USR2" generate 
			PHY: LH_PHYRxUSR2_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHYUSR2Rx;									
	
	Gen_PHYUSR3Rx:if Rate = "USR3" generate 
			PHY: LH_PHYRxUSR3_x1
			    port map
			    (   
					reconfig_write          => reconfig_write,
					reconfig_read           => reconfig_read,       
					reconfig_address        => reconfig_address,    
					reconfig_writedata      => reconfig_writedata,  
					reconfig_readdata       => open,   
					reconfig_waitrequest    => open,
					reconfig_clk            => clk_100,					
					reconfig_reset          => Reset_in,				
					rx_analogreset          => rx_analogreset(i downto i),                        
					rx_analogreset_stat     => rx_analogreset_stat(i downto i), 			               
					rx_cal_busy             => rx_cal_busy(i downto i),                           
					rx_cdr_refclk0          => refclk,                                            
					rx_clkout               => rx_clkout(i downto i),                             
					rx_coreclkin            => rx_clkout(i downto i),                                                                        
					rx_digitalreset         => rx_digitalreset(i downto i),                       
					rx_digitalreset_stat    => rx_digitalreset_stat(i downto i),			               
					rx_is_lockedtodata      => rx_is_lockedtodata(i downto i),                          
					rx_is_lockedtoref       => open,                                              
					rx_parallel_data        => rx_parallel_data64(i),                               
					rx_serial_data          => rx_serial_data(i downto i),                        
					unused_rx_parallel_data => open
					);
			end generate Gen_PHYUSR3Rx;		
						  				                                                                  
		RST: ResetRx
		    port map
		    (   
				clock                 => clk_100(0),
				reset                 => Reset_in(0),
				rx_analogreset        => rx_analogreset(i downto i),     
				rx_analogreset_stat   => rx_analogreset_stat(i downto i),
				rx_cal_busy           => rx_cal_busy(i downto i),
				rx_digitalreset       => rx_digitalreset(i downto i),      
				rx_digitalreset_stat  => rx_digitalreset_stat(i downto i), 
				rx_is_lockedtodata    => rx_is_lockedtodata(i downto i),
				rx_ready              => open
			);		
		
--		DataPathSel: DataMux64
--			port map
--			(   
--				Reset									=> rx_digitalreset_stat(i),
--				rx_parallel_datain   	=> rx_parallel_data64(i),
--				rx_clk								=> rx_clkout(i),
--				tx_parallel_dataout		=> open, --tx_parallel_data64(i),
--				tx_clk								=> rx_clkout(i),  --tx_clkout(i),
--				Traffic_Tx_parallel_datain	=> x"BCBCBCBC" & x"BCBCBCBC"	-- just putting control characters on here for now.
--			);	

		rxclkout(i) <= rx_clkout(i);
	
	end generate;     




end rtl;
